@@ -83,7 +83,8 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
     # region client parameters
     we_api_base_host: str = "\u0061pi-\u0061pp.w\u0065-\u0061pi.com"
     we_api_base_url: str = "https://\u0061pi-\u0061pp.w\u0065-\u0061pi.com/\u0061pi"
-    ws_we_api_base_url: str = "wss://ws-market-swap.w\u0065-\u0061pi.com/ws"
+    ws_we_api_base_url: str = "wss://ws-market-sw\u0061p.w\u0065-\u0061pi.com/ws"
+    f_ws_we_api_base_url: str = "wss://f-ws-\u0061pp.w\u0065-\u0061pi.com/market"
     original_base_host: str = "https://\u0062ing\u0078.co\u006d"
     qq_os_base_host: str = "https://\u0061pi-\u0061pp.\u0071\u0071-os.com"
     qq_os_base_url: str = "https://\u0061pi-\u0061pp.\u0071\u0071-os.com/\u0061pi"
@@ -283,7 +284,7 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
 
     # endregion
     ###########################################################
-    # region ws-subscribes
+    # region ws last-candle methods
     async def do_price_subscribe(self) -> None:
         """
         Subscribes to the price changes coming from the exchange.
@@ -922,6 +923,9 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
     ) -> UnifiedTraderPositions:
         perp_positions = []
         std_positions = []
+        perp_ex: str = None
+        std_ex: str = None
+
         try:
             result = await self.get_unified_trader_positions_perp(
                 uid=uid,
@@ -930,7 +934,7 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
             perp_positions = result.positions
         except Exception as ex:
             if not no_warn:
-                logger.warning(f"Failed to fetch perp positions of {uid}: {ex}")
+                perp_ex = f"{ex}"
 
         try:
             result = await self.get_unified_trader_positions_std(
@@ -939,7 +943,13 @@ class BXUltraClient(ExchangeBase, IPriceFetcher):
             std_positions = result.positions
         except Exception as ex:
             if not no_warn:
-                logger.warning(f"Failed to fetch std positions of {uid}: {ex}")
+                std_ex = f"{ex}"
+
+        if not perp_positions and not std_positions:
+            if perp_ex:
+                logger.warning(f"Failed to fetch perp positions of {uid}: {perp_ex}")
+            if std_ex:
+                logger.warning(f"Failed to fetch std positions of {uid}: {std_ex}")
 
         unified_result = UnifiedTraderPositions()
         unified_result.positions = perp_positions + std_positions
